//
//  CPDFFreeTextViewController.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFFreeTextViewController.h"
#import "CPDFAnnotationBaseViewController_Header.h"
#import "CPDFThicknessSliderView.h"
#import "CPDFFontStyleTableView.h"

@interface CPDFFreeTextViewController () <CPDFThicknessSliderViewDelegate, CPDFFontStyleTableViewDelegate>

@property (nonatomic, strong) UIButton *fontStyleBtn;

@property (nonatomic, strong) UIButton *boldBtn;

@property (nonatomic, strong) UIButton *underlineBtn;

@property (nonatomic, strong) UILabel *alignmentLabel;

@property (nonatomic, strong) UIButton *leftBtn;

@property (nonatomic, strong) UIButton *centerBtn;

@property (nonatomic, strong) UIButton *rightBtn;

@property (nonatomic, strong) CPDFThicknessSliderView *fontsizeSliderView;

@property (nonatomic, assign) BOOL isBold;

@property (nonatomic, assign) BOOL isUnderline;

@property (nonatomic, strong) CPDFFontStyleTableView *fontStyleTableView;

@end

@implementation CPDFFreeTextViewController

#pragma mark - ViewController Methods

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.fontStyleBtn = [[UIButton alloc] init];
    [self.fontStyleBtn setTitle:NSLocalizedString(@"Font Style", nil) forState:UIControlStateNormal];
    [self.fontStyleBtn setTitleColor:[UIColor blueColor] forState:UIControlStateNormal];
    [self.fontStyleBtn addTarget:self action:@selector(buttonItemClicked_FontStyle:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.fontStyleBtn];
    
    self.boldBtn = [[UIButton alloc] init];
    [self.boldBtn setImage:[UIImage imageNamed:@"CPDFFreeTextImageBold" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [self.boldBtn addTarget:self action:@selector(buttonItemClicked_Bold:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.boldBtn];
    
    self.underlineBtn = [[UIButton alloc] init];
    [self.underlineBtn setImage:[UIImage imageNamed:@"CPDFFreeTextImageUnderline" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [self.underlineBtn addTarget:self action:@selector(buttonItemClicked_Underline:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.underlineBtn];
    
    self.alignmentLabel = [[UILabel alloc] init];
    self.alignmentLabel.text = NSLocalizedString(@"Alignment Mode", nil);
    self.alignmentLabel.adjustsFontSizeToFitWidth = YES;
    [self.view addSubview:self.alignmentLabel];
    
    self.leftBtn = [[UIButton alloc] init];
    [self.leftBtn setImage:[UIImage imageNamed:@"CPDFFreeTextImageLeft" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [self.leftBtn addTarget:self action:@selector(buttonItemClicked_Left:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.leftBtn];
    
    self.centerBtn = [[UIButton alloc] init];
    [self.centerBtn setImage:[UIImage imageNamed:@"CPDFFreeTextImageCenter" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [self.centerBtn addTarget:self action:@selector(buttonItemClicked_Center:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.centerBtn];
    
    self.rightBtn = [[UIButton alloc] init];
    [self.rightBtn setImage:[UIImage imageNamed:@"CPDFFreeTextImageRight" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [self.rightBtn addTarget:self action:@selector(buttonItemClicked_Right:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.rightBtn];
    
    self.fontsizeSliderView = [[CPDFThicknessSliderView alloc] init];
    self.fontsizeSliderView.thicknessSlider.value = 20;
    self.fontsizeSliderView.thicknessSlider.minimumValue = 1;
    self.fontsizeSliderView.thicknessSlider.maximumValue = 100;
    self.fontsizeSliderView.titleLabel.text = NSLocalizedString(@"Font Size", nil);
    self.fontsizeSliderView.startLabel.text = @"1";
    self.fontsizeSliderView.endLabel.text = @"100";
    self.fontsizeSliderView.delegate = self;
    self.fontsizeSliderView.autoresizingMask = UIViewAutoresizingFlexibleWidth;
    [self.view addSubview:self.fontsizeSliderView];
    
    self.isBold = NO;
    self.isUnderline = NO;
}

- (void)viewWillLayoutSubviews {
    [super viewWillLayoutSubviews];
    self.fontStyleBtn.frame = CGRectMake(10, 370, 180, 45);
    self.boldBtn.frame = CGRectMake(self.view.frame.size.width - 80, 385, 30, 30);
    self.underlineBtn.frame = CGRectMake(self.view.frame.size.width - 40, 385, 30, 30);
    self.alignmentLabel.frame = CGRectMake(10, 415, 120, 45);
    self.leftBtn.frame = CGRectMake(self.view.frame.size.width - 120, 430, 30, 30);
    self.centerBtn.frame = CGRectMake(self.view.frame.size.width - 80, 430, 30, 30);
    self.rightBtn.frame = CGRectMake(self.view.frame.size.width - 40, 430, 30, 30);
    self.fontsizeSliderView.frame = CGRectMake(10, 450, self.view.frame.size.width - 20, 90);
}

#pragma mark - Protect Mehtods

- (void)commomInitTitle {
    self.titleLabel.text = NSLocalizedString(@"Free Text", nil);
    self.sampleView.selecIndex = CPDFSamplesFreeText;
    self.sampleView.fontName = @"Helvetica";
    self.sampleView.fillColor = [UIColor blueColor];
    self.sampleView.thickness = 20;
}

- (void)updatePreferredContentSizeWithTraitCollection:(UITraitCollection *)traitCollection {
    self.preferredContentSize = CGSizeMake(self.view.bounds.size.width, traitCollection.verticalSizeClass == UIUserInterfaceSizeClassCompact ? 270 : 600);
}

#pragma mark - Action

- (void)buttonItemClicked_Bold:(id)sender {
    self.isBold = !(self.isBold);
    self.sampleView.isBold = self.isBold;
    [self.sampleView setNeedsDisplay];
}

- (void)buttonItemClicked_Underline:(id)sender {
    self.isUnderline = !(self.isUnderline);
    self.sampleView.isUnderline = self.isUnderline;
    [self.sampleView setNeedsDisplay];
}

- (void)buttonItemClicked_FontStyle:(id)sender {
    self.fontStyleTableView = [[CPDFFontStyleTableView alloc] initWithFrame:self.view.bounds];
    self.fontStyleTableView.delegate = self;
    self.fontStyleTableView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    [self.view addSubview:self.fontStyleTableView];
}

- (void)buttonItemClicked_Left:(id)sender {
    
}

- (void)buttonItemClicked_Center:(id)sender {
    
}

- (void)buttonItemClicked_Right:(id)sender {
    
}

#pragma mark - CPDFThicknessSliderViewDelegate

- (void)thicknessSliderView:(CPDFThicknessSliderView *)thicknessSliderView thickness:(CGFloat)thickness {
    self.sampleView.thickness = thickness;
    [self.sampleView setNeedsDisplay];
}

#pragma mark - CPDFFontStyleTableViewDelegate

- (void)fontStyleTableView:(CPDFFontStyleTableView *)fontStyleTableView fontName:(NSString *)fontName {
    self.sampleView.fontName = fontName;
    [self.sampleView setNeedsDisplay];
}

@end
